library (ggplot2)
library (nlme)
library (lme4)
library(readxl)
library(QuantPsyc)

#Read in data
data <- read_excel("PATH/Publish_Data.xlsx")

data$Condition = factor(data$Condition,levels=c("gen","pers","nofb"))
data$PTSD = factor(data$PTSD,levels=c("yes","no"))
data$Exposure = factor(data$Exposure,levels=c("1","2"))

View(data)


#Mean + SD
mean(data$Motivation_Overall)
sd(data$Motivation_Overall)
NullMoti = lm(Motivation_Overall ~ 1, data = data)
summary(NullMoti)

mean(data$Trust_Overall)
sd(data$Trust_Overall)
NullTrust = lm(Trust_Overall ~ 1, data = data)
summary(NullTrust)

mean(data$FBH)
sd(data$FBH)
NullFBH = lm(FBH ~ 1, data = data)
summary(NullFBH)

dataca <- read_excel("PATH/Publish_AllianceData.xlsx")
cronbach(dataca)


#Condition effect on outcome measures

# Motivation 
AnovaMoti = lm(Motivation_Overall ~ Condition, data = data)
summary(AnovaMoti)
ggplot(data, aes(x=Motivation_Overall, fill=Condition)) + geom_density(alpha = 0.3)

dataSG <-subset(data, (Condition == "gen" | Condition =="pers"))
AnovaMoti = lm(Motivation_Overall ~ Condition, data = dataSG)
summary(AnovaMoti)

dataNG <-subset(data, (Condition == "gen" | Condition =="nofb"))
AnovaMoti = lm(Motivation_Overall ~ Condition, data = dataNG)
summary(AnovaMoti)

dataSN <-subset(data, (Condition == "nofb" | Condition =="pers"))
AnovaMoti = lm(Motivation_Overall ~ Condition, data = dataSN)
summary(AnovaMoti)

#Trust
AnovaTrust = lm(Trust_Overall ~ Condition, data = data)
summary(AnovaTrust)
ggplot(data, aes(x=Trust_Overall, fill=Condition)) + geom_density(alpha = 0.3)

AnovaTrust = lm(Trust_Overall ~ Condition, data = dataSG)
summary(AnovaTrust)
AnovaTrust = lm(Trust_Overall ~ Condition, data = dataNG)
summary(AnovaTrust)
AnovaTrust = lm(Trust_Overall ~ Condition, data = dataSN)
summary(AnovaTrust)


#FBH
AnovaAlli = lm(FBH ~ Condition, data = data)
summary(AnovaAlli)
ggplot(data, aes(x=FBH, fill=Condition)) + geom_density(alpha = 0.3)

AnovaAlli = lm(FBH ~ Condition, data = dataSG)
summary(AnovaAlli)
AnovaAlli = lm(FBH ~ Condition, data = dataNG)
summary(AnovaAlli)
AnovaAlli = lm(FBH ~ Condition, data = dataSN)
summary(AnovaAlli)


#PTSD/EXPOSURE effect on overall measures

#PTSD on Motivation
AnovaMoti = lm(Motivation_Overall ~ PTSD, data = data)
summary(AnovaMoti)
ggplot(data, aes(x=Motivation_Overall, fill=PTSD)) + geom_density(alpha = 0.3)

#PTSD on Trust
AnovaTrust = lm(Trust_Overall ~ PTSD, data = data)
summary(AnovaTrust)
ggplot(data, aes(x=Trust_Overall, fill=PTSD)) + geom_density(alpha = 0.3)

#PTSD on FBH
AnovaAlli = lm(FBH ~ PTSD, data = data)
summary(AnovaAlli)
ggplot(data, aes(x=FBH, fill=PTSD)) + geom_density(alpha = 0.3)

#Exposure on Motivation
AnovaMoti = lm(Motivation_Overall ~ Exposure, data = data)
summary(AnovaMoti)
ggplot(data, aes(x=Motivation_Overall, fill=Exposure)) + geom_density(alpha = 0.3)

#Exposure on Trust
AnovaTrust = lm(Trust_Overall ~ Exposure, data = data)
summary(AnovaTrust)
ggplot(data, aes(x=Trust_Overall, fill=Exposure)) + geom_density(alpha = 0.3)

#Exposure on FBH
AnovaAlli = lm(FBH ~ Exposure, data = data)
summary(AnovaAlli)
ggplot(data, aes(x=FBH, fill=Exposure)) + geom_density(alpha = 0.3)


#Analysis per situation
data2 <- read_excel("PATH/Publish_Data_PerSituation.xlsx")

data2$Condition = factor(data2$Condition,levels=c("gen","pers","nofb"))

data2$PCLTrend = factor(data2$PCLTrend,levels=c("Rising","Stable","Dropping"))
data2$PCLTrend <- ordered(data2$PCLTrend)

data2$TrustSit = factor(data2$TrustSit,levels=c("Low","Doubt","High"))
data2$TrustSit <- ordered(data2$TrustSit)

data2$PPnr = factor(data2$PPnr)

View(data2)


#Effect of situation (Separated into PCLTrend/TrustSit) on motivation & trust?
ModelM1_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = data2, method = "ML")
ModelM1_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = data2, method = "ML")
anova(ModelM1_0,ModelM1_1)
ModelM1_2 <- lme(fixed = Motivation_perSituation~PCLTrend+Condition, random = ~1 | PPnr, data = data2, method = "ML")
anova(ModelM1_1,ModelM1_2)
ModelM1_3 <- lme(fixed = Motivation_perSituation~PCLTrend+TrustSit+Condition, random = ~1 | PPnr, data = data2, method = "ML") 
anova(ModelM1_2,ModelM1_3)
ModelM1_4 <- lme(fixed = Motivation_perSituation~PCLTrend+TrustSit+Condition+PCLTrend:TrustSit, random = ~1 | PPnr, data = data2, method = "ML") 
anova(ModelM1_3,ModelM1_4)
ModelM1_5 <- lme(fixed = Motivation_perSituation~PCLTrend+TrustSit+Condition+Condition:PCLTrend+PCLTrend:TrustSit, random = ~1 | PPnr, data = data2, method = "ML") 
anova(ModelM1_4,ModelM1_5)
ModelM1_6 <- lme(fixed = Motivation_perSituation~PCLTrend+TrustSit+Condition+Condition:TrustSit+Condition:PCLTrend+PCLTrend:TrustSit, random = ~1 | PPnr, data = data2, method = "ML") 
anova(ModelM1_5,ModelM1_6)
ModelM1_7 <- lme(fixed = Motivation_perSituation~PCLTrend+TrustSit+Condition+Condition:TrustSit+Condition:PCLTrend+PCLTrend:TrustSit+Condition:TrustSit:PCLTrend, random = ~1 | PPnr, data = data2, method = "ML") 
anova(ModelM1_6,ModelM1_7)

#Significance tests per 2 for graphs
#PCL Trend
dataRS  <-subset(data2, (PCLTrend == "Rising" | PCLTrend =="Stable"))
ModelM1_P <- lme(fixed = Motivation_perSituation~PCLTrend, random = ~1 | PPnr, data = dataRS, method = "ML")
summary(ModelM1_P)
dataRG  <-subset(data2, (PCLTrend == "Rising" | PCLTrend =="Dropping"))
ModelM1_P2 <- lme(fixed = Motivation_perSituation~PCLTrend, random = ~1 | PPnr, data = dataRG, method = "ML")
summary(ModelM1_P2)
dataSG  <-subset(data2, (PCLTrend == "Stable" | PCLTrend =="Dropping"))
ModelM1_P3 <- lme(fixed = Motivation_perSituation~PCLTrend, random = ~1 | PPnr, data = dataSG, method = "ML")
summary(ModelM1_P3)

dataRS  <-subset(data2, (PCLTrend == "Rising" | PCLTrend =="Stable"))
ModelT1_P <- lme(fixed = TrusTrust_perSituationituation~PCLTrend, random = ~1 | PPnr, data = dataRS, method = "ML")
summary(ModelT1_P)
dataRG  <-subset(data2, (PCLTrend == "Rising" | PCLTrend =="Dropping"))
ModelT1_P2 <- lme(fixed = TrusTrust_perSituationituation~PCLTrend, random = ~1 | PPnr, data = dataRG, method = "ML")
summary(ModelT1_P2)
dataSG  <-subset(data2, (PCLTrend == "Stable" | PCLTrend =="Dropping"))
ModelT1_P3 <- lme(fixed = TrusTrust_perSituationituation~PCLTrend, random = ~1 | PPnr, data = dataSG, method = "ML")
summary(ModelT1_P3)

#Different trusts
dataRS  <-subset(data2, (TrustSit == "Low" | TrustSit =="Medium"))
ModelM1_P <- lme(fixed = Motivation_perSituation~TrustSit, random = ~1 | PPnr, data = dataRS, method = "ML")
summary(ModelM1_P)
dataRG  <-subset(data2, (TrustSit == "Low" | TrustSit =="High"))
ModelM1_P2 <- lme(fixed = Motivation_perSituation~TrustSit, random = ~1 | PPnr, data = dataRG, method = "ML")
summary(ModelM1_P2)
dataSG  <-subset(data2, (TrustSit == "Medium" | TrustSit =="High"))
ModelM1_P3 <- lme(fixed = Motivation_perSituation~TrustSit, random = ~1 | PPnr, data = dataSG, method = "ML")
summary(ModelM1_P3)

dataRS  <-subset(data2, (TrustSit == "Low" | TrustSit =="Medium"))
ModelT1_P <- lme(fixed = TrusTrust_perSituationituation~TrustSit, random = ~1 | PPnr, data = dataRS, method = "ML")
summary(ModelT1_P)
dataRG  <-subset(data2, (TrustSit == "Low" | TrustSit =="High"))
ModelT1_P2 <- lme(fixed = TrusTrust_perSituationituation~TrustSit, random = ~1 | PPnr, data = dataRG, method = "ML")
summary(ModelT1_P2)
dataSG  <-subset(data2, (TrustSit == "Medium" | TrustSit =="High"))
ModelT1_P3 <- lme(fixed = TrusTrust_perSituationituation~TrustSit, random = ~1 | PPnr, data = dataSG, method = "ML")
summary(ModelT1_P3)

#Different message types
dataRS  <-subset(data2, (Condition == "gen" | Condition =="nofb"))
ModelM1_P <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataRS, method = "ML")
summary(ModelM1_P)
dataRG  <-subset(data2, (Condition == "gen" | Condition =="pers"))
ModelM1_P2 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataRG, method = "ML")
summary(ModelM1_P2)
dataSG  <-subset(data2, (Condition == "nofb" | Condition =="pers"))
ModelM1_P3 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataSG, method = "ML")
summary(ModelM1_P3)

dataRS  <-subset(data2, (Condition == "gen" | Condition =="nofb"))
ModelT1_P <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataRS, method = "ML")
summary(ModelT1_P)
dataRG  <-subset(data2, (Condition == "gen" | Condition =="pers"))
ModelT1_P2 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataRG, method = "ML")
summary(ModelT1_P2)
dataSG  <-subset(data2, (Condition == "nofb" | Condition =="pers"))
ModelT1_P3 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataSG, method = "ML")
summary(ModelT1_P3)



ModelT1_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = data2, method = "ML")
ModelT1_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = data2, method = "ML")
anova(ModelT1_0,ModelT1_1)
ModelT1_2 <- lme(fixed = TrusTrust_perSituationituation~PCLTrend+Condition, random = ~1 | PPnr, data = data2, method = "ML")
anova(ModelT1_1,ModelT1_2)
ModelT1_3 <- lme(fixed = TrusTrust_perSituationituation~PCLTrend+TrustSit+Condition, random = ~1 | PPnr, data = data2, method = "ML") 
anova(ModelT1_2,ModelT1_3)
ModelT1_4 <- lme(fixed = TrusTrust_perSituationituation~PCLTrend+TrustSit+Condition+PCLTrend:TrustSit, random = ~1 | PPnr, data = data2, method = "ML") 
anova(ModelT1_3,ModelT1_4)
ModelT1_5 <- lme(fixed = TrusTrust_perSituationituation~PCLTrend+TrustSit+Condition+Condition:PCLTrend+PCLTrend:TrustSit, random = ~1 | PPnr, data = data2, method = "ML") 
anova(ModelT1_4,ModelT1_5)
ModelT1_6 <- lme(fixed = TrusTrust_perSituationituation~PCLTrend+TrustSit+Condition+Condition:TrustSit+Condition:PCLTrend+PCLTrend:TrustSit, random = ~1 | PPnr, data = data2, method = "ML") 
anova(ModelT1_5,ModelT1_6)
ModelT1_7 <- lme(fixed = TrusTrust_perSituationituation~PCLTrend+TrustSit+Condition+Condition:TrustSit+Condition:PCLTrend+PCLTrend:TrustSit+Condition:TrustSit:PCLTrend, random = ~1 | PPnr, data = data2, method = "ML") 
anova(ModelT1_6,ModelT1_7)


#Comparison effect condition on trust & motivation per situation

  #PCLTrend
dataD  <-subset(data2, (PCLTrend=="Dropping"))
ggplot(dataD, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataD, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataD, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataD, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataD, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataD, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#Uitwerking vergelijking 2 condities STABLE
dataD_SG  <-subset(dataD, (Condition == "gen" | Condition =="pers"))
ggplot(dataD_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataD_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataD_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataD_SG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataD_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataD_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataD_NG  <-subset(dataD, (Condition == "gen" | Condition =="nofb"))
ggplot(dataD_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataD_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataD_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataD_NG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataD_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataD_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataD_SN  <-subset(dataD, (Condition == "nofb" | Condition =="pers"))
ggplot(dataD_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataD_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataD_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataD_SN, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataD_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataD_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)


#STABLE

dataS  <-subset(data2, (PCLTrend=="Stable"))
ggplot(dataS, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataS, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataS, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataS, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataS, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataS, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#Uitwerking vergelijking 2 condities STABLE
dataS_SG  <-subset(dataS, (Condition == "gen" | Condition =="pers"))
ggplot(dataS_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataS_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataS_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataS_SG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataS_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataS_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataS_NG  <-subset(dataS, (Condition == "gen" | Condition =="nofb"))
ggplot(dataS_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataS_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataS_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataS_NG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataS_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataS_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataS_SN  <-subset(dataS, (Condition == "nofb" | Condition =="pers"))
ggplot(dataS_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataS_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataS_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataS_SN, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataS_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataS_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#RISING

dataR  <-subset(data2, (PCLTrend=="Rising"))
ggplot(dataR, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataR, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataR, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataR, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataR, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataR, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#Uitwerking vergelijking 2 condities RISING
dataR_SG  <-subset(dataR, (Condition == "gen" | Condition =="pers"))
ggplot(dataR_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataR_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataR_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataR_SG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataR_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataR_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataR_NG  <-subset(dataR, (Condition == "gen" | Condition =="nofb"))
ggplot(dataR_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataR_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataR_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataR_NG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataR_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataR_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataR_SN  <-subset(dataR, (Condition == "nofb" | Condition =="pers"))
ggplot(dataR_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataR_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataR_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataR_SN, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataR_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataR_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

   #TRUST

#LOW TRUST

dataL  <-subset(data2, (TrustSit=="Low"))
ggplot(dataL, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataL, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataL, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataL, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataL, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataL, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)


#Uitwerking vergelijking 2 condities LOW
dataL_SG  <-subset(dataL, (Condition == "gen" | Condition =="pers"))
ggplot(dataL_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataL_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataL_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataL_SG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataL_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataL_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataL_NG  <-subset(dataL, (Condition == "gen" | Condition =="nofb"))
ggplot(dataL_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataL_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataL_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataL_NG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataL_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataL_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataL_SN  <-subset(dataL, (Condition == "nofb" | Condition =="pers"))
ggplot(dataL_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataL_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataL_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataL_SN, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataL_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataL_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#MEDIUM
dataM  <-subset(data2, (TrustSit=="Doubt"))
ggplot(dataM, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataM, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataM, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataM, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataM, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataM, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#Uitwerking vergelijking 2 condities MEDIUM
dataM_SG  <-subset(dataM, (Condition == "gen" | Condition =="pers"))
ggplot(dataM_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataM_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataM_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataM_SG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataM_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataM_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataM_NG  <-subset(dataM, (Condition == "gen" | Condition =="nofb"))
ggplot(dataM_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataM_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataM_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataM_NG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataM_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataM_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataM_SN  <-subset(dataM, (Condition == "nofb" | Condition =="pers"))
ggplot(dataM_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataM_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataM_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataM_SN, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataM_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataM_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#HIGH
dataH  <-subset(data2, (TrustSit=="High"))
ggplot(dataH, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataH, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataH, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataH, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataH, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataH, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#Uitwerking vergelijking 2 condities HIGH
dataH_SG  <-subset(dataH, (Condition == "gen" | Condition =="pers"))
ggplot(dataH_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataH_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataH_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataH_SG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataH_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataH_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataH_NG  <-subset(dataH, (Condition == "gen" | Condition =="nofb"))
ggplot(dataH_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataH_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataH_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataH_NG, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataH_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataH_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataH_SN  <-subset(dataH, (Condition == "nofb" | Condition =="pers"))
ggplot(dataH_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataH_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataH_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataH_SN, aes(x=TrusTrust_perSituationituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = TrusTrust_perSituationituation~1, random = ~1 | PPnr, data = dataH_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = TrusTrust_perSituationituation~Condition, random = ~1 | PPnr, data = dataH_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)


#TEST Comparison effect condition on trust & motivation per situation - SEPARATE FACTORS!

#PCLTrend
dataD  <-subset(data2, (PCLTrend=="D"))
ggplot(dataD, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataD, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataD, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataD, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataD, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataD, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#Uitwerking vergelijking 2 condities STABLE
dataD_SG  <-subset(dataD, (Condition == "gen" | Condition =="pers"))
ggplot(dataD_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataD_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataD_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataD_SG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataD_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataD_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataD_NG  <-subset(dataD, (Condition == "gen" | Condition =="nofb"))
ggplot(dataD_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataD_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataD_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataD_NG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataD_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataD_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataD_SN  <-subset(dataD, (Condition == "nofb" | Condition =="pers"))
ggplot(dataD_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataD_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataD_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataD_SN, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataD_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataD_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)


#STABLE

dataS  <-subset(data2, (PCLTrend=="S"))
ggplot(dataS, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataS, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataS, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataS, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataS, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataS, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#Uitwerking vergelijking 2 condities STABLE
dataS_SG  <-subset(dataS, (Condition == "gen" | Condition =="pers"))
ggplot(dataS_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataS_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataS_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataS_SG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataS_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataS_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataS_NG  <-subset(dataS, (Condition == "gen" | Condition =="nofb"))
ggplot(dataS_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataS_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataS_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataS_NG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataS_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataS_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataS_SN  <-subset(dataS, (Condition == "nofb" | Condition =="pers"))
ggplot(dataS_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataS_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataS_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataS_SN, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataS_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataS_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#RISING

dataR  <-subset(data2, (PCLTrend=="R"))
ggplot(dataR, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataR, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataR, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataR, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataR, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataR, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#Uitwerking vergelijking 2 condities RISING
dataR_SG  <-subset(dataR, (Condition == "gen" | Condition =="pers"))
ggplot(dataR_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataR_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataR_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataR_SG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataR_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataR_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataR_NG  <-subset(dataR, (Condition == "gen" | Condition =="nofb"))
ggplot(dataR_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataR_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataR_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataR_NG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataR_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataR_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataR_SN  <-subset(dataR, (Condition == "nofb" | Condition =="pers"))
ggplot(dataR_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataR_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataR_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataR_SN, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataR_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataR_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#TRUST

#LOW TRUST

dataL  <-subset(data2, (TrustSit=="L"))
ggplot(dataL, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataL, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataL, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataL, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataL, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataL, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)


#Uitwerking vergelijking 2 condities LOW
dataL_SG  <-subset(dataL, (Condition == "gen" | Condition =="pers"))
ggplot(dataL_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataL_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataL_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataL_SG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataL_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataL_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataL_NG  <-subset(dataL, (Condition == "gen" | Condition =="nofb"))
ggplot(dataL_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataL_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataL_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataL_NG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataL_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataL_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataL_SN  <-subset(dataL, (Condition == "nofb" | Condition =="pers"))
ggplot(dataL_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataL_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataL_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataL_SN, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataL_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataL_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#MEDIUM
dataM  <-subset(data2, (TrustSit=="M"))
ggplot(dataM, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataM, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataM, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataM, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataM, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataM, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#Uitwerking vergelijking 2 condities MEDIUM
dataM_SG  <-subset(dataM, (Condition == "gen" | Condition =="pers"))
ggplot(dataM_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataM_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataM_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataM_SG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataM_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataM_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataM_NG  <-subset(dataM, (Condition == "gen" | Condition =="nofb"))
ggplot(dataM_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataM_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataM_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataM_NG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataM_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataM_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataM_SN  <-subset(dataM, (Condition == "nofb" | Condition =="pers"))
ggplot(dataM_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataM_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataM_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataM_SN, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataM_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataM_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#HIGH
dataH  <-subset(data2, (TrustSit=="H"))
ggplot(dataH, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ggplot(dataH, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)

ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataH, method = "ML")
summary(ModelMPCL_0)
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataH, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)

ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataH, method = "ML")
summary(ModelTPCL_0)
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataH, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

#Uitwerking vergelijking 2 condities HIGH
dataH_SG  <-subset(dataH, (Condition == "gen" | Condition =="pers"))
ggplot(dataH_SG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataH_SG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataH_SG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataH_SG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataH_SG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataH_SG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataH_NG  <-subset(dataH, (Condition == "gen" | Condition =="nofb"))
ggplot(dataH_NG, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataH_NG, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataH_NG, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataH_NG, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataH_NG, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataH_NG, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)

dataH_SN  <-subset(dataH, (Condition == "nofb" | Condition =="pers"))
ggplot(dataH_SN, aes(x=Motivation_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelMPCL_0 <- lme(fixed = Motivation_perSituation~1, random = ~1 | PPnr, data = dataH_SN, method = "ML")
ModelMPCL_1 <- lme(fixed = Motivation_perSituation~Condition, random = ~1 | PPnr, data = dataH_SN, method = "ML")
summary(ModelMPCL_1)
anova(ModelMPCL_0,ModelMPCL_1)
ggplot(dataH_SN, aes(x=Trust_perSituation, fill=Condition)) + geom_density(alpha = 0.3)
ModelTPCL_0 <- lme(fixed = Trust_perSituation~1, random = ~1 | PPnr, data = dataH_SN, method = "ML")
ModelTPCL_1 <- lme(fixed = Trust_perSituation~Condition, random = ~1 | PPnr, data = dataH_SN, method = "ML")
summary(ModelTPCL_1)
anova(ModelTPCL_0,ModelTPCL_1)